#include "stdafx.h"
#include "resource.h"
#include <stdio.h>

#define MAX_LOADSTRING 100
#define TMSG_CONNECT 0x100
#define TMSG_DISCONNECT 0x101
#define TMSG_ACK 0x400
#define TMSG_RELAYS 0x110
#define TMSG_SPEED 0x111
#define TMSG_GOTO_RADEC 0x112
#define TMSG_RESYNC 0x113
#define TMSG_FOCUS 0x114
#define TMSG_STOPGOTO 0x115
#define TMSG_GET_MOVING 0x120
#define TMSG_GET_RADEC 0x121
#define TMSG_GET_ALTAZI 0x122
#define TTD_S 0x8
#define TTD_N 0x4
#define TTD_E 0x2
#define TTD_W 0x1
#define TTF_IN 0x10
#define TTF_OUT 0x11
#define TTF_STOP 0x12
#define TTF_FAST 0x13
#define TTF_SLOW 0x14
#define TTACK_SPEED 0x1
#define TTACK_GOTO 0x2
#define TTACK_RESYNC 0x4
#define TTACK_FOCUS 0x8
#define TTACK_READPOS 0x10

UINT WM_TELESCOPE;
HINSTANCE hInst;								
TCHAR szTitle[MAX_LOADSTRING];					
TCHAR szWindowClass[MAX_LOADSTRING];
char TelCommand[30];			

ATOM				MyRegisterClass(HINSTANCE hInstance);
BOOL				InitInstance(HINSTANCE, int);
LRESULT CALLBACK	WndProc(HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK	About(HWND, UINT, WPARAM, LPARAM);

int APIENTRY WinMain(HINSTANCE hInstance,   
                     HINSTANCE hPrevInstance,
                     LPSTR     lpCmdLine,
                     int       nCmdShow)
{
	MSG msg;
	HACCEL hAccelTable;
	WM_TELESCOPE = RegisterWindowMessage("AA_TELESCOPE");
	strcpy(TelCommand,"Waiting ...");
	LoadString(hInstance, IDS_APP_TITLE, szTitle, MAX_LOADSTRING);
	LoadString(hInstance, IDC_CLIENT, szWindowClass, MAX_LOADSTRING);
	MyRegisterClass(hInstance);
	if (!InitInstance (hInstance, nCmdShow)) 
	{
		return FALSE;
	}
	hAccelTable = LoadAccelerators(hInstance, (LPCTSTR)IDC_CLIENT);
	while (GetMessage(&msg, NULL, 0, 0)) 
	{
		if (!TranslateAccelerator(msg.hwnd, hAccelTable, &msg)) 
		{
			TranslateMessage(&msg);
			DispatchMessage(&msg);
		}
	}
	return msg.wParam;
}


ATOM MyRegisterClass(HINSTANCE hInstance)
{
	WNDCLASSEX wcex;

	wcex.cbSize = sizeof(WNDCLASSEX); 
	wcex.style			= CS_HREDRAW | CS_VREDRAW;
	wcex.lpfnWndProc	= (WNDPROC)WndProc;
	wcex.cbClsExtra		= 0;
	wcex.cbWndExtra		= 0;
	wcex.hInstance		= hInstance;
	wcex.hIcon			= LoadIcon(hInstance, (LPCTSTR)IDI_CLIENT);
	wcex.hCursor		= LoadCursor(NULL, IDC_ARROW);
	wcex.hbrBackground	= (HBRUSH)(COLOR_WINDOW+1);
	wcex.lpszMenuName	= NULL;
	wcex.lpszClassName	= szWindowClass;
	wcex.hIconSm		= LoadIcon(wcex.hInstance, (LPCTSTR)IDI_SMALL);
	return RegisterClassEx(&wcex);
}

BOOL InitInstance(HINSTANCE hInstance, int nCmdShow)
{
 HWND hWnd;

   hInst = hInstance; 
   hWnd = CreateWindow(szWindowClass, szTitle, WS_OVERLAPPEDWINDOW,
      CW_USEDEFAULT, 0,200, 150, NULL, NULL, hInstance, NULL);
   if (!hWnd)
   {
      return FALSE;
   }
   ShowWindow(hWnd, nCmdShow);
   UpdateWindow(hWnd);
   return TRUE;
}

LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
 PAINTSTRUCT ps;
 HDC hdc;
 float ra,de;
 int r;

    r = 0;
    if (message == WM_TELESCOPE)
	{
		switch (wParam)
		{
			case TMSG_CONNECT:
				strcpy(TelCommand,"CONNECTED");
				SendMessage((HWND)lParam,WM_TELESCOPE,TMSG_ACK + TTACK_GOTO + 
					 TTACK_READPOS + TTACK_RESYNC + TTACK_SPEED + TTACK_FOCUS,(int)hWnd);
				break;
			case TMSG_DISCONNECT:
				strcpy(TelCommand,"DISCONNECTED");
				break;
			case TMSG_SPEED:
				sprintf(TelCommand,"SPEED: %d",lParam);
				break;
			case TMSG_RELAYS:
				strcpy(TelCommand," ");
				if ((lParam & TTD_N) != 0) strcat(TelCommand,"NORTH ");
				if ((lParam & TTD_S) != 0) strcat(TelCommand,"SOUTH ");
				if ((lParam & TTD_E) != 0) strcat(TelCommand,"EAST ");
				if ((lParam & TTD_W) != 0) strcat(TelCommand,"WEST ");
				break;
			case TMSG_GOTO_RADEC:
				ra = (float)(lParam & 0xffff) / 2700;
				de = (float)(lParam >> 16 & 0xffff) / 360 - 90;
				sprintf(TelCommand,"GOTO: %6g %6g",ra,de);
				r = TTACK_GOTO;
				break;
			case TMSG_GET_MOVING:
				r = 0; 
				break;
		}
		InvalidateRgn(hWnd,NULL,TRUE);
		return r;		
	};
	switch (message) 
	{
		case WM_PAINT:
			hdc = BeginPaint(hWnd, &ps);
			RECT rt;
			GetClientRect(hWnd, &rt);
			DrawText(hdc, TelCommand, strlen(TelCommand), &rt, DT_CENTER+DT_VCENTER+DT_SINGLELINE);
			EndPaint(hWnd, &ps);
			break;
		case WM_DESTROY:
			PostQuitMessage(0);
			break;
		default:
			return DefWindowProc(hWnd, message, wParam, lParam);
   }
   return 0;
}


